FullstoryPipelineOwner class final

A Fullstory-instrumented version of PipelineOwner.

This root pipeline owner performs all standard responsibilities, as well as tracking render-tree nodes which need paint or layout so that these invalidations can be used for view scanning.

Inheritance

Constructors

FullstoryPipelineOwner()

Properties

debugDoingLayout bool
Whether this pipeline is currently in the layout phase.
no setterinherited
debugDoingPaint bool
Whether this pipeline is currently in the paint phase.
no setterinherited
debugOutstandingSemanticsHandles int
Deprecated.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
nodesNeedingLayout Iterable<RenderObject>
The RenderObjects representing relayout boundaries which need to be laid out in the next flushLayout pass.
no setterinherited
nodesNeedingPaint Iterable<RenderObject>
The RenderObjects which need to be painted in the next flushPaint pass.
no setterinherited
onNeedVisualUpdate VoidCallback?
Called when a render object associated with this pipeline owner wishes to update its visual appearance.
finalinherited
onSemanticsOwnerCreated VoidCallback?
Called whenever this pipeline owner creates a semantics object.
finalinherited
onSemanticsOwnerDisposed VoidCallback?
Called whenever this pipeline owner disposes its semantics owner.
finalinherited
onSemanticsUpdate SemanticsUpdateCallback?
Called whenever this pipeline owner's semantics owner emits a SemanticsUpdate.
finalinherited
rootNode RenderObject?
The unique object managed by this pipeline that has no parent.
getter/setter pairinherited-getteroverride-setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsOwner SemanticsOwner?
The object that is managing semantics for this pipeline owner, if any.
no setterinherited

Methods

adoptChild(PipelineOwner child) → void
Adds child to this PipelineOwner.
inherited
attach(PipelineManifold manifold) → void
Mark this PipelineOwner as attached to the given PipelineManifold.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
detach() → void
Mark this PipelineOwner as detached.
inherited
dispose() → void
Release any resources held by this pipeline owner.
inherited
dropChild(PipelineOwner child) → void
Removes a child PipelineOwner previously added via adoptChild.
inherited
ensureSemantics({VoidCallback? listener}) SemanticsHandle
Deprecated.
inherited
flushCompositingBits() → void
Updates the RenderObject.needsCompositing bits.
inherited
flushLayout() → void
Update the layout information for all dirty render objects.
override
flushPaint() → void
Update the display lists for all render objects.
override
flushSemantics() → void
Update the semantics for render objects marked as needing a semantics update.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestVisualUpdate() → void
Calls onNeedVisualUpdate if onNeedVisualUpdate is not null.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
visitAndClearInvalidated(void visitor(RenderObject, bool)) → void
visitChildren(PipelineOwnerVisitor visitor) → void
Calls visitor for each immediate child of this PipelineOwner.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited