flushLayout method

  1. @override
void flushLayout()
override

Update the layout information for all dirty render objects.

This function is one of the core stages of the rendering pipeline. Layout information is cleaned prior to painting so that render objects will appear on screen in their up-to-date locations.

See RendererBinding for an example of how this function is used.

Implementation

@override
void flushLayout() {
  _cacheLayoutNodes();
  super.flushLayout();
}