rootNode property
The unique object managed by this pipeline that has no parent.
Implementation
RenderObject? get rootNode => _rootNode;
Implementation
@override
set rootNode(RenderObject? _) {
assert(() {
throw FlutterError.fromParts(<DiagnosticsNode>[
ErrorSummary(
'Cannot set a rootNode on the Fullstory root pipeline owner.',
),
ErrorDescription(
'By default, the RendererBinding.rootPipelineOwner is not configured '
'to manage a root node because this pipeline owner does not define a '
'proper onSemanticsUpdate callback to handle semantics for that node.',
),
ErrorHint(
'Typically, the root pipeline owner does not manage a root node. '
'Instead, properly configured child pipeline owners (which do manage '
'root nodes) are added to it. Alternatively, if you do want to set a '
'root node for the root pipeline owner, override '
'RendererBinding.createRootPipelineOwner to create a '
'pipeline owner that is configured to properly handle semantics for '
'the provided root node.',
),
]);
}());
}