FullstoryBinding class

A web stub of the Fullstory-instrumented WidgetsFlutterBinding.

We instruct customers to call FullstoryBinding.ensureInitialized in place of WidgetsFlutterBinding.ensureInitialized(). On web there is no Fullstory instrumentation. This stub allows the app to call ensureInitialized() without error, but it does not do anything else, and the app will run with the default Flutter binding and no Fullstory behavior.

Constructors

FullstoryBinding()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

ensureInitialized() WidgetsBinding
Returns the default WidgetsFlutterBinding on web, instead of the FullstoryBinding used on mobile.