runFullstoryWidget function
Runs the given app inside a Fullstory-instrumented binding.
On web there is no Fullstory binding, so this is equivalent to calling the standard runWidget. The remaining parameters are accepted for API compatibility with the mobile implementation and are ignored.
Like with runWidget, this will not wrap the passed app with a default
View, so be sure to provide your own!
logScanMetrics indicates whether to log view scan metrics to the console.
This is intended for debugging and performance tuning, and will negatively
impact performance if enabled in production. By default, enabled in debug
only.
shortenSelectors indicates whether some widgets which are typically
implementation details of others are hidden from the selectors created
during scans. This defaults to true, and typically should only be set to
false for debugging, as there is a performance cost associated with
deeper selectors.
captureImages controls whether images and chart painters are
rasterized into color grids for playback. Adds CPU overhead (~50% in
profiling). Defaults to false while the feature stabilizes; set to true
to enable.
rasterizers configures render objects that should be captured as raster
images, for custom-drawn widgets (such as third-party charts) that
Fullstory can't otherwise capture. Empty by default, and only applies when
captureImages is true.
logLevel is deprecated. Instead, set the logLevel for the Android and iOS
SDKs.
Implementation
void runFullstoryWidget(
Widget app, {
LogLevel logLevel = LogLevel.note,
bool logScanMetrics = kDebugMode,
bool shortenSelectors = true,
bool captureImages = false,
Set<Rasterizer> rasterizers = const {},
}) {
// Web is not supported; run the widget with the default binding.
runWidget(app);
}