FS class
Fullstory API
Note that all methods are static. Also note that methods may drop data if called when there is no Fullstory session active.
APIs cannot be called on background isolates. This is a known issue that will be addressed in a future version.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Static Methods
-
addStatusListener(
FSStatusListener listener) → void - Add a delegate to be notified of Fullstory session status events.
-
anonymize(
) → Future< void> - If a user ID was previously set via FS.identify, this will end the session, clear the user ID, and begin a new anonymous session.
-
captureErrors(
{void errorHandler(Object? exception, StackTrace? stack)?}) → void - Configures Flutter to send errors to Fullstory for handling.
-
consent(
bool consented) → Future< void> - Configure Fullstory to enable/disable capturing elements that have been configured to "Capture data wiht user constent" in Fullstory's privacy settings.
-
crashEvent(
{String name = 'Flutter crash', Object? exception, StackTrace? stackTrace}) → Future< void> - Report a crash to Fullstory for display in playback.
-
currentSessionURL(
{bool now = false}) → Future< String?> - Returns the URL to view the current Fullstory session.
-
event(
String name, [Map< String, Object?> properties = const {}]) → Future<void> - Create a custom event that will appear in the event list in playback and can be used in segments, funnels, etc.
-
identify(
String uid, [Map< String, Object?> ? userVars]) → Future<void> - Identify a user and associate current and future sessions with that user.
-
log(
{FSLogLevel level = FSLogLevel.info, required String message}) → Future< void> - Log a message that will appear in the Dev Tools > Console section of the Fullstory replay.
-
networkEvent(
{required String url, required String method, int? statusCode, int? durationMs, int? requestSize, int? responseSize}) → Future< void> - Create a network event in the Dev Log in playback.
-
page(
String pageName, {Map< String, Object?> ? properties}) → FSPage - Create a Fullstory Page object
-
removeStatusListener(
FSStatusListener listener) → void - Remove a previously added status listener.
-
resetIdleTimer(
) → Future< void> - Reset the idle timer and prevent Fullstory from going into a lower-fidelity mode that conserves power and bandwidth.
-
restart(
) → Future< void> - Start or resume a Fullstory session.
-
setStatusListener(
FSStatusListener? listener) → void - Specify a delegate to be notified of Fullstory session status events.
-
setUserVars(
Map< String, Object?> userVars) → Future<void> - Set arbitrary key/value pairs that are associated with the current user.
-
shutdown(
) → Future< void> - End Fullstory session.