consent static method
Configure Fullstory to enable/disable capturing elements that have been configured to "Capture data wiht user constent" in Fullstory's privacy settings.
FS.consent(true) must be called to begin capturing elements that have been configured to capture with user consent.
For more information, see https://developer.fullstory.com/mobile/android/fullcapture/user-consent/
Implementation
static Future<void> consent(bool consented) {
return FullstoryFlutterPlatform.instance.consent(consented);
}