event static method
Create a custom event that will appear in the event list in playback and can be used in segments, funnels, etc.
For more information, see https://developer.fullstory.com/mobile/flutter/capture-events/analytics-events/
Implementation
static Future<void> event(
String name, [
Map<String, Object?> properties = const {},
]) {
return FullstoryFlutterPlatform.instance.event(
name: name,
properties: properties,
);
}