fullstory_flutter library

Classes

FS
Fullstory API
FSCustomAttributes
Allows annotation of child with classes and attributes to be shown in Fullstory session replay.
FSExclude
Excludes child (and its descendants) from Fullstory capture.
FSMask
Marks child (and its descendants) as masked.
FSNavigatorObserver
A NavigatorObserver that tracks Navigator page transitions and captures them in Fullstory.
FSPage
Fullstory Page object
FSUnmask
Marks child (and its descendants) as unmasked.
FullstoryBinding
A Fullstory-instrumented version of WidgetsFlutterBinding.
FullstoryPipelineOwner
A Fullstory-instrumented version of PipelineOwner.
PrivacyWidget
A widget which applies an in-code privacy rule to child.
Rasterizer<T extends RenderBox>
Configuration for a render object type that Fullstory should capture as a raster image.

Enums

FSLogLevel
Log levels. Controls how logs appear in the Dev tools > Console section of a Fullstory session replay
LogLevel

Mixins

FSStatusListener
Fullstory session status listener mixin

Functions

namePageDefault(Route route) String
Default page name generator. Uses the name set in RouteSettings, such as with Navigator.pushNamed.
propertiesDefault(Route current, Route? previous) Map<String, Object?>?
Default null PagePropertiesFactory.
runFullstoryApp(Widget app, {LogLevel logLevel = LogLevel.note, bool logScanMetrics = kDebugMode, bool shortenSelectors = true, bool captureImages = true, bool capturePainters = false, Set<Rasterizer<RenderBox>> rasterizers = const {}}) → void
Runs the given app inside a Fullstory-instrumented binding.
runFullstoryWidget(Widget app, {LogLevel logLevel = LogLevel.note, bool logScanMetrics = kDebugMode, bool shortenSelectors = true, bool captureImages = true, bool capturePainters = false, Set<Rasterizer<RenderBox>> rasterizers = const {}}) → void
Runs the given app inside a Fullstory-instrumented binding.

Typedefs

PagePropertiesFactory = Map<String, Object?>? Function(Route current, Route? previous)
Function used to generate or update properties for a page when transitioning from previous to current.