hash abstract method

int hash(
  1. T instance
)
override

A hash of the contents of instance that changes whenever it needs to be re-rasterized, such as when a chart's data, viewport, or text scale changes. If this throws, a warning is logged and the widget is re-rasterized on every scan instead of being cached.

Implementation

int hash(T instance);