matches method

bool matches(
  1. RenderBox box
)

Whether box should be rasterized by this rasterizer.

The result is cached per runtime type, so this must depend only on the type of box, not on its state.

Implementation

bool matches(RenderBox box) => box is T;