binding_stub library
This library provides stub APIs to be used on web.
Since the mobile implementation relies heavily on FFI, it cannot compile for web. This file offers the minimal API surface needed for apps to use the full version on mobile and still allow compilation for web, without Fullstory enabled.
Classes
- FullstoryBinding
- A web stub of the Fullstory-instrumented WidgetsFlutterBinding.
Enums
- LogLevel
- The level to log a message at; used for filtering messages by importance.
Functions
-
runFullstoryApp(
Widget app, {LogLevel logLevel = LogLevel.note, bool logScanMetrics = kDebugMode, bool shortenSelectors = true, bool captureImages = false}) → void - Runs the given app inside a Fullstory-instrumented binding.
-
runFullstoryWidget(
Widget app, {LogLevel logLevel = LogLevel.note, bool logScanMetrics = kDebugMode, bool shortenSelectors = true, bool captureImages = false}) → void - Runs the given app inside a Fullstory-instrumented binding.