runFullstoryApp function

void runFullstoryApp(
  1. Widget app, {
  2. LogLevel logLevel = LogLevel.note,
  3. bool logScanMetrics = kDebugMode,
  4. bool shortenSelectors = true,
  5. bool captureImages = false,
})

Runs the given app inside a Fullstory-instrumented binding.

On web there is no Fullstory binding, so this is equivalent to calling the standard runApp. The remaining parameters are accepted for API compatibility with the mobile implementation and are ignored.

logScanMetrics indicates whether to log view scan metrics to the console. This is intended for debugging and performance tuning, and will negatively impact performance if enabled in production. By default, enabled in debug only.

shortenSelectors indicates whether some widgets which are typically implementation details of others are hidden from the selectors created during scans. This defaults to true, and typically should only be set to false for debugging, as there is a performance cost associated with deeper selectors.

captureImages controls whether images, icon glyphs, and chart painters are rasterized into color grids for playback. Adds CPU overhead (~50% in profiling). Defaults to false while the feature stabilizes; set to true to enable.

logLevel is deprecated. Instead, set the logLevel for the Android and iOS SDKs.

Implementation

void runFullstoryApp(
  Widget app, {
  LogLevel logLevel = LogLevel.note,
  bool logScanMetrics = kDebugMode,
  bool shortenSelectors = true,
  bool captureImages = false,
}) {
  // Web is not supported; run the app with the default binding.
  runApp(app);
}