Deobfuscator class
Deobfuscates public class names using the mapping file generated at build time.
- Available extensions
Constructors
-
Deobfuscator(Map<
String, String> _map)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether the mapping is empty, which may indicate that the file was missing
or had no public class entries after filtering.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deobfuscate(
Object object) → String - Deobfuscates public class names using the mapping file generated at build time.
-
deobfuscate(
Object object) → String -
Available on Deobfuscator?, provided by the NullableDeobfuscator extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMapContent(
String? content) → Future< Deobfuscator> -
Loads the mapping data from
contentand uses it for a new Deobfuscator instance.