isEmpty property
bool
get
isEmpty
Whether the mapping is empty, which may indicate that the file was missing or had no public class entries after filtering.
This is always true for unobfuscated builds.
Implementation
bool get isEmpty => _map.isEmpty;